==> haskell-hw-prim-0.6.3.2-205.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-prim.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-prim
version:              0.6.3.2
visibility:           public
id:                   hw-prim-0.6.3.2-5c08O4eG9tbdUtI2RIXPT
key:                  hw-prim-0.6.3.2-5c08O4eG9tbdUtI2RIXPT
license:              BSD-3-Clause
copyright:            2016-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
stability:            Experimental
homepage:             http://github.com/haskell-works/hw-prim#readme
synopsis:             Primitive functions and data types
description:          Primitive functions and data types.
category:             Data
abi:                  34ed4cd916d255822db173a73839349b
exposed:              True
exposed-modules:
    HaskellWorks.Control.Monad.Lazy HaskellWorks.Data.AtIndex
    HaskellWorks.Data.Branchless HaskellWorks.Data.ByteString
    HaskellWorks.Data.ByteString.Builder
    HaskellWorks.Data.ByteString.Lazy HaskellWorks.Data.Char
    HaskellWorks.Data.Char.IsChar HaskellWorks.Data.Concat
    HaskellWorks.Data.Cons HaskellWorks.Data.Container
    HaskellWorks.Data.Decode HaskellWorks.Data.Drop
    HaskellWorks.Data.Empty HaskellWorks.Data.Filter
    HaskellWorks.Data.Foldable HaskellWorks.Data.FromByteString
    HaskellWorks.Data.FromForeignRegion HaskellWorks.Data.FromString
    HaskellWorks.Data.Generate HaskellWorks.Data.Head
    HaskellWorks.Data.Length HaskellWorks.Data.Naive
    HaskellWorks.Data.Null HaskellWorks.Data.Ops
    HaskellWorks.Data.Positioning HaskellWorks.Data.Product
    HaskellWorks.Data.Search HaskellWorks.Data.Sign
    HaskellWorks.Data.Snoc HaskellWorks.Data.Take
    HaskellWorks.Data.TreeCursor HaskellWorks.Data.Uncons
    HaskellWorks.Data.Unsign HaskellWorks.Data.Unsnoc
    HaskellWorks.Data.Vector.AsVector64
    HaskellWorks.Data.Vector.AsVector64ns
    HaskellWorks.Data.Vector.AsVector64s
    HaskellWorks.Data.Vector.AsVector8
    HaskellWorks.Data.Vector.AsVector8ns
    HaskellWorks.Data.Vector.AsVector8s
    HaskellWorks.Data.Vector.BoxedVectorLike
    HaskellWorks.Data.Vector.Storable
    HaskellWorks.Data.Vector.StorableVectorLike HaskellWorks.Data.Word
    HaskellWorks.Foreign

hidden-modules:       Paths_hw_prim
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hw-prim-0.6.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hw-prim-0.6.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hw-prim-0.6.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-prim
hs-libraries:         HShw-prim-0.6.3.2-5c08O4eG9tbdUtI2RIXPT
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1 ghc-prim-0.10.0
    mmap-0.5.9-AiaaDT3AznV3aaEfoYTVVt transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-hw-prim/html/hw-prim.haddock
haddock-html:         /usr/share/doc/haskell-hw-prim/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hw-prim-0.6.3.2-206-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-prim.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-prim
version:              0.6.3.2
visibility:           public
id:                   hw-prim-0.6.3.2-ASd2zWZ81uRBD3E6eicDiz
key:                  hw-prim-0.6.3.2-ASd2zWZ81uRBD3E6eicDiz
license:              BSD-3-Clause
copyright:            2016-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
stability:            Experimental
homepage:             http://github.com/haskell-works/hw-prim#readme
synopsis:             Primitive functions and data types
description:          Primitive functions and data types.
category:             Data
abi:                  2f1c9f921178ee779315f20e0e6db0fa
exposed:              True
exposed-modules:
    HaskellWorks.Control.Monad.Lazy HaskellWorks.Data.AtIndex
    HaskellWorks.Data.Branchless HaskellWorks.Data.ByteString
    HaskellWorks.Data.ByteString.Builder
    HaskellWorks.Data.ByteString.Lazy HaskellWorks.Data.Char
    HaskellWorks.Data.Char.IsChar HaskellWorks.Data.Concat
    HaskellWorks.Data.Cons HaskellWorks.Data.Container
    HaskellWorks.Data.Decode HaskellWorks.Data.Drop
    HaskellWorks.Data.Empty HaskellWorks.Data.Filter
    HaskellWorks.Data.Foldable HaskellWorks.Data.FromByteString
    HaskellWorks.Data.FromForeignRegion HaskellWorks.Data.FromString
    HaskellWorks.Data.Generate HaskellWorks.Data.Head
    HaskellWorks.Data.Length HaskellWorks.Data.Naive
    HaskellWorks.Data.Null HaskellWorks.Data.Ops
    HaskellWorks.Data.Positioning HaskellWorks.Data.Product
    HaskellWorks.Data.Search HaskellWorks.Data.Sign
    HaskellWorks.Data.Snoc HaskellWorks.Data.Take
    HaskellWorks.Data.TreeCursor HaskellWorks.Data.Uncons
    HaskellWorks.Data.Unsign HaskellWorks.Data.Unsnoc
    HaskellWorks.Data.Vector.AsVector64
    HaskellWorks.Data.Vector.AsVector64ns
    HaskellWorks.Data.Vector.AsVector64s
    HaskellWorks.Data.Vector.AsVector8
    HaskellWorks.Data.Vector.AsVector8ns
    HaskellWorks.Data.Vector.AsVector8s
    HaskellWorks.Data.Vector.BoxedVectorLike
    HaskellWorks.Data.Vector.Storable
    HaskellWorks.Data.Vector.StorableVectorLike HaskellWorks.Data.Word
    HaskellWorks.Foreign

hidden-modules:       Paths_hw_prim
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hw-prim-0.6.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hw-prim-0.6.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hw-prim-0.6.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-prim
hs-libraries:         HShw-prim-0.6.3.2-ASd2zWZ81uRBD3E6eicDiz
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1 ghc-prim-0.10.0
    mmap-0.5.9-AiaaDT3AznV3aaEfoYTVVt transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-hw-prim/html/hw-prim.haddock
haddock-html:         /usr/share/doc/haskell-hw-prim/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
